@@ -1,4 +1,4 @@
-# @CODE:TRUST-001:VALIDATOR | SPEC: SPEC-TRUST-001.md
+# @CODE:TRUST-001:VALIDATOR | SPEC: SPEC-TRUST-001/spec.md
 """Base validator class and validation result"""
 
 from dataclasses import dataclass
@@ -7,7 +7,7 @@ from typing import Any
 
 @dataclass
 class ValidationResult:
-    """검증 결과 데이터 클래스"""
+    """Validation result data class"""
 
     passed: bool
     message: str
